==> pytool-3.16.3.tar.gz: pytool-3.16.3/README.md <==
# Pytool Package

`pytool`` is a collection of often used
helper methods and classes that make life easier or fill in gaps in the
Python Standard Library.

Pytool is compatible with and tested against Python 3.8 and higher. End of life Python versions are not supported.

> [!NOTE] > _Note_: Python 2 and `<3.8` is now [End of
> Life](https://www.python.org/doc/sunset-python-2/) and support in Pytool
> is deprecated and will be removed in Pytool 4.x.

Pytool's source is hosted on Github: <https://github.com/shakefu/pytool>

Any comments, issues or requests should be submitted via Github:
<https://github.com/shakefu/pytool/issues>

[![image](https://travis-ci.com/shakefu/pytool.svg?branch=master)](https://travis-ci.com/shakefu/pytool)

[![image](https://coveralls.io/repos/shakefu/pytool/badge.svg?branch=master&service=github)](https://coveralls.io/github/shakefu/pytool?branch=master)

## Documentation

Read the [complete
documentation](https://pytool.readthedocs.org/en/latest/) on [Read the
Docs](https://readthedocs.org)!

## Installation

Pytool is available on PyPI for your installation ease.

```bash
pip install pytool
```

## Usage

Pytool is a collection of common and useful functions designed to help
your code be easier to read, write and maintain. The API is well
documented with examples of how they might be used.

See the [complete
documentation](https://pytool.readthedocs.org/en/latest/) on Read The
Docs for more information.

## Contributors

- [shakefu](https://github.com/shakefu) (creator, maintainer)
- [dshen109](https://github.com/dshen109) (contributor)
- [abendig](https://github.com/abendig)

==> pytool-4.0.0.tar.gz: pytool-4.0.0/README.md <==
# Pytool Package

`pytool` is a collection of often used
helper methods and classes that make life easier or fill in gaps in the
Python Standard Library.

Pytool is compatible with and tested against Python 3.8 and higher. End of life Python versions are not supported.

> [!NOTE]
> Pytool 4.x is a major release that is not backwards compatible with earlier
> versions. It now requires Python 3.8 or higher, and adds Python 3 type
> annotations among other improvements. New features will only be added to the
> 4.x release line.

Pytool's source is hosted on Github: <https://github.com/shakefu/pytool>

Any comments, issues or requests should be submitted via Github:
<https://github.com/shakefu/pytool/issues>

![CI](https://github.com/shakefu/pytool/actions/workflows/ci.yaml/badge.svg)
[![Coveralls](https://coveralls.io/repos/shakefu/pytool/badge.svg?branch=master&service=github)](https://coveralls.io/github/shakefu/pytool?branch=master)

## Documentation

Read the [complete
documentation](https://pytool.readthedocs.org/en/latest/) on [Read the
Docs](https://readthedocs.org)!

## Installation

Pytool is available on PyPI for your installation ease.

```bash
pip install pytool
```

## Usage

Pytool is a collection of common and useful functions designed to help
your code be easier to read, write and maintain. The API is well
documented with examples of how they might be used.

See the [complete
documentation](https://pytool.readthedocs.org/en/latest/) on Read The
Docs for more information.

## Contributors

- [shakefu](https://github.com/shakefu) (creator, maintainer)
- [dshen109](https://github.com/dshen109) (contributor)
- [abendig](https://github.com/abendig)
